@@ -98,7 +98,7 @@ def consistency_checker(location, value, info, consistency_check, imas_version):
         elif 'INT' in info['data_type']:
             value = int(value)
     # structure type is respected check type
-    if info['data_type'] == 'structure' and not isinstance(value, ODS):
+    if 'data_type' in info and info['data_type'] == 'structure' and not isinstance(value, ODS):
         text = 'Trying to write %s in %s but this should be an ODS' % (type(value), location)
         if consistency_check == 'warn':
             printe(text)
@@ -272,11 +272,16 @@ class ODS(MutableMapping):
                 # Collapse extra dimensions, assuming time is the last one. If it isn't, this will fail.
                 while len(time0.shape) > 1:
                     time0 = numpy.take(time0, 0, axis=0)
-                for time in times.values():
-                    # Make sure all time arrays are close to the time0 we identified
-                    assert abs(time - time0).max() < 1e-7
-                extra_info['homogeneous_time'] = True
-                return time0
+
+                if all([time.size==time0.size for time in times.values()]):
+                    for time in times.values():
+                        # Make sure all time arrays are close to the time0 we identified
+                        assert abs(time - time0).max() < 1e-7
+                    extra_info['homogeneous_time'] = True
+                    return time0
+                else: # Similar to ValueError exception caught above
+                    extra_info['homogeneous_time'] = False
+                    return None
             # there are inconsistencies with different ways of specifying times in the IDS
             else:
                 raise ValueError('Inconsistent time definitions in %s' % times.keys())
@@ -1002,7 +1007,7 @@ class ODS(MutableMapping):
         return paths
 
     def pretty_paths(self, **kw):
-        """
+        r"""
         Traverse the ods and return paths that have data formatted nicely
 
         :param \**kw: extra keywords passed to the path() method
@@ -1012,7 +1017,7 @@ class ODS(MutableMapping):
         return list(map(l2i, self.paths(**kw)))
 
     def full_paths(self, **kw):
-        """
+        r"""
         Traverse the ods and return paths from root of ODS that have data
 
         :param \**kw: extra keywords passed to the path() method
@@ -1023,7 +1028,7 @@ class ODS(MutableMapping):
         return [location + path for path in self.paths(**kw)]
 
     def flat(self, **kw):
-        """
+        r"""
         Flat dictionary representation of the data
 
         :param \**kw: extra keywords passed to the path() method
@@ -1093,7 +1098,7 @@ class ODS(MutableMapping):
         return s, []
 
     def get(self, key, default=None):
-        """
+        r"""
         Check if key is present and if not return default value without creating value in omas data structure
 
         :param key: ods location
@@ -1766,7 +1771,7 @@ class CodeParameters(dict):
         return list(dict.items(self))
 
     def flat(self, **kw):
-        """
+        r"""
         Flat dictionary representation of the data
 
         :param \**kw: extra keywords passed to the path() method
