@@ -619,13 +619,13 @@ def load_omas_iter_scenario(pulse, run=0, paths=None,
     :return: OMAS data set
     """
     # set MDSPLUS_TREE_BASE_? environment variables as per
-    # imasdb /work/imas/shared/iterdb/3 ; env | grep MDSPLUS_TREE_BASE
+    # imasdb /work/imas/shared/imasdb/3 ; env | grep MDSPLUS_TREE_BASE
     try:
         bkp_imas_environment = {}
         for k in range(10):
             if 'MDSPLUS_TREE_BASE_%d' % k in os.environ:
                 bkp_imas_environment['MDSPLUS_TREE_BASE_%d' % k] = os.environ['MDSPLUS_TREE_BASE_%d' % k]
-            os.environ['MDSPLUS_TREE_BASE_%d' % k] = '/work/imas/shared/iterdb/3/%d' % k
+            os.environ['MDSPLUS_TREE_BASE_%d' % k] = '/work/imas/shared/imasdb/3/%d' % k
 
         # load data from imas
         ods = load_omas_imas(user=None, machine=None, pulse=pulse, run=run, paths=paths, imas_version=imas_version, verbose=verbose)
