@@ -21,6 +21,9 @@ def generate_xml_schemas(imas_version=None):
     """
     import subprocess
 
+    saxon_version = 'SaxonHE9-9-1-4J'
+    saxon_major_version = '9.' + saxon_version.split('-')[1]
+
     # clone the IMAS data-dictionary repository
     dd_folder = os.sep.join([imas_json_dir, '..', 'data-dictionary'])
     if not os.path.exists(dd_folder):
@@ -29,13 +32,13 @@ def generate_xml_schemas(imas_version=None):
             stdout=subprocess.PIPE, shell=True).communicate()[0]
 
     # download Saxon
-    sax_folder = os.sep.join([imas_json_dir, '..', 'SaxonHE9-6-0-10J'])
+    sax_folder = os.sep.join([imas_json_dir, '..', saxon_version])
     if not os.path.exists(sax_folder):
         subprocess.Popen("""
-        cd %s
-        curl https://netcologne.dl.sourceforge.net/project/saxon/Saxon-HE/9.6/SaxonHE9-6-0-10J.zip > SaxonHE9-6-0-10J.zip
-        unzip -d SaxonHE9-6-0-10J SaxonHE9-6-0-10J.zip
-        rm SaxonHE9-6-0-10J.zip""" % os.sep.join([imas_json_dir, '..']), shell=True).communicate()
+        cd {install_dir}
+        curl https://iweb.dl.sourceforge.net/project/saxon/Saxon-HE/9.9/{saxon_version}.zip > {saxon_version}.zip
+        unzip -d {saxon_version} {saxon_version}.zip
+        rm {saxon_version}.zip""".format(install_dir=os.sep.join([imas_json_dir, '..']), saxon_major_version=saxon_major_version, saxon_version=saxon_version), shell=True).communicate()
 
     # fetch data structure updates
     subprocess.Popen("""
@@ -57,7 +60,7 @@ def generate_xml_schemas(imas_version=None):
     # generate IDSDef.xml files for given imas_version
     _imas_version = imas_versions[imas_version]
     executable = """
-export CLASSPATH={imas_json_dir}/../SaxonHE9-6-0-10J/saxon9he.jar;
+export CLASSPATH={imas_json_dir}/../{saxon_version}/saxon9he.jar;
 cd {dd_folder}
 git checkout {tag}
 git pull
@@ -67,7 +70,7 @@ make
 rm -rf {imas_json_dir}/{_imas_version}/
 mkdir {imas_json_dir}/{_imas_version}/
 cp IDSDef.xml {imas_json_dir}/{_imas_version}/
-""".format(tag=imas_version, _imas_version=_imas_version, imas_json_dir=imas_json_dir, dd_folder=dd_folder)
+""".format(tag=imas_version, _imas_version=_imas_version, imas_json_dir=imas_json_dir, dd_folder=dd_folder, saxon_version=saxon_version)
     print(executable)
     subprocess.Popen(executable, shell=True).communicate()
 
@@ -231,7 +234,6 @@ def create_json_structure(imas_version=omas_rcparams['default_imas_version']):
             continue
         print(imas_json_dir + os.sep + imas_versions.get(imas_version, imas_version) + os.sep + structure + '.json')
         dump_string = json.dumps(hout[structure], default=json_dumper, indent=1, separators=(',', ': '), sort_keys=True)
-        # dump_string = pickle.dumps(hout[structure],protocol=pickle.HIGHEST_PROTOCOL)
         open(imas_json_dir + os.sep + imas_versions.get(imas_version, imas_version) + os.sep + structure + '.json', 'w').write(dump_string)
 
     # generate coordinates cache file
@@ -336,3 +338,58 @@ def extract_coordinates(imas_version=omas_rcparams['default_imas_version']):
         omas_coordinates.update(coords)
 
     return sorted(list(omas_coordinates))
+
+
+def symlink_imas_structure_versions(test=True, verbose=True):
+    '''
+    Generate symbolic links in imas_structures so that no files are added when there are no changes between IDSs
+
+    :param test: whether to actually apply symlink commands
+
+    :param verbose: wheter to print to screen structures strides
+
+    :returns: dictionary with structure stides per IDS
+    '''
+
+    import subprocess
+    from pprint import pprint
+    from omas.omas_setup import IMAS_versions
+    from omas.omas_utils import dict_structures, imas_json_dir
+
+    imas_versions = IMAS_versions('tagged')
+
+    # check if two files are identical
+    def same_ds(a, b):
+        with open(a) as a:
+            with open(b) as b:
+                return a.read() == b.read()
+
+    # see when DS files have changed
+    structures_strides = {}
+    previous_tag_structures = {}
+    for version in list(imas_versions.keys()):
+        this_tag_structures = dict_structures(version)
+        for ds in this_tag_structures:
+            if ds not in structures_strides:
+                structures_strides[ds] = [[version]]
+            elif ds in previous_tag_structures:
+                if same_ds(previous_tag_structures[ds], this_tag_structures[ds]):
+                    structures_strides[ds][-1].append(version)
+                else:
+                    structures_strides[ds].append([version])
+        previous_tag_structures = this_tag_structures
+    if verbose:
+        pprint(structures_strides)
+
+    if not test:
+        for ds in structures_strides:
+            for stride in structures_strides[ds]:
+                if len(stride) > 1:
+                    for version in stride[:-1]:
+                        dir = imas_json_dir + '/'
+                        this = dict_structures(stride[-1])[ds][len(dir):]
+                        prev = dict_structures(version)[ds]
+                        command = 'cd %s; ln -s -f ../%s %s' % (os.path.dirname(prev), this, os.path.basename(prev))
+                        print(command)
+                        subprocess.Popen(command, shell=True).communicate()
+    return structures_strides
\ No newline at end of file
