@@ -12,7 +12,7 @@ import sys
 # --------------------------------------------
 # ODS utilities
 # --------------------------------------------
-def different_ods(ods1, ods2):
+def different_ods(ods1, ods2, ignore_type=False, ignore_empty=False, prepend_path_string=''):
     """
     Checks if two ODSs have any difference and returns the string with the cause of the different
 
@@ -20,32 +20,44 @@ def different_ods(ods1, ods2):
 
     :param ods2: second ods to check
 
+    :param ignore_type: ignore object type differences
+
+    :param ignore_empty: ignore emptry nodes
+
     :return: string with reason for difference, or False otherwise
     """
-    ods1 = ods1.flat()
-    ods2 = ods2.flat()
+    from omas import ODS, CodeParameters
+
+    ods1 = ods1.flat(return_empty_leaves=True)
+    ods2 = ods2.flat(return_empty_leaves=True)
 
     k1 = set(ods1.keys())
     k2 = set(ods2.keys())
     differences = []
     for k in k1.difference(k2):
-        if not k.startswith('info.'):
-            differences.append('DIFF: key `%s` missing in 2nd ods' % k)
+        if not k.startswith('info.') and not (ignore_empty and isinstance(ods1[k], ODS) and not len(ods1[k])):
+            differences.append('DIFF: key `%s` missing in 2nd ods' % (prepend_path_string + k))
     for k in k2.difference(k1):
-        if not k.startswith('info.'):
-            differences.append('DIFF: key `%s` missing in 1st ods' % k)
+        if not k.startswith('info.') and not (ignore_empty and isinstance(ods2[k], ODS) and not len(ods2[k])):
+            differences.append('DIFF: key `%s` missing in 1st ods' % (prepend_path_string + k))
     for k in k1.intersection(k2):
-        if isinstance(ods1[k], basestring) and isinstance(ods2[k], basestring):
+        if ods1[k] is None and ods2[k] is None:
+            pass
+        elif isinstance(ods1[k], basestring) and isinstance(ods2[k], basestring):
             if ods1[k] != ods2[k]:
-                differences.append('DIFF: `%s` differ in value' % k)
-        elif type(ods1[k]) != type(ods2[k]):
-            differences.append('DIFF: `%s` differ in type (%s,%s)' % (k, type(ods1[k]), type(ods2[k])))
+                differences.append('DIFF: `%s` differ in value' % (prepend_path_string + k))
+        elif not ignore_type and type(ods1[k]) != type(ods2[k]):
+            differences.append('DIFF: `%s` differ in type (%s,%s)' % ((prepend_path_string + k), type(ods1[k]), type(ods2[k])))
         elif numpy.atleast_1d(is_uncertain(ods1[k])).any() or numpy.atleast_1d(is_uncertain(ods2[k])).any():
             if not numpy.allclose(nominal_values(ods1[k]), nominal_values(ods2[k]), equal_nan=True) or not numpy.allclose(std_devs(ods1[k]), std_devs(ods2[k]), equal_nan=True):
-                differences.append('DIFF: `%s` differ in value' % k)
+                differences.append('DIFF: `%s` differ in value' % (prepend_path_string + k))
+        elif isinstance(ods1[k], CodeParameters) and isinstance(ods2[k], CodeParameters):
+            tmp = different_ods(ods1[k], ods2[k], ignore_type=ignore_type, ignore_empty=ignore_empty, prepend_path_string=k + '.')
+            if tmp:
+                differences.extend(tmp)
         else:
             if not numpy.allclose(ods1[k], ods2[k], equal_nan=True):
-                differences.append('DIFF: `%s` differ in value' % k)
+                differences.append('DIFF: `%s` differ in value' % (prepend_path_string + k))
     if len(differences):
         return differences
     else:
@@ -164,9 +176,11 @@ def json_dumper(obj, objects_encode=True):
     if isinstance(obj, ODS):
         return obj.omas_data
 
-    if not objects_encode:
+    if objects_encode is False:
         if isinstance(obj, numpy.ndarray):
             return obj.tolist()
+        elif sys.version_info >= (3, 0) and isinstance(obj, (range, map)):
+            return list(obj)
         elif isinstance(obj, numpy.generic):
             return obj.item()
         else:
@@ -197,6 +211,8 @@ def json_dumper(obj, objects_encode=True):
                     return dict(__ndarray_tolist__=obj.tolist(),
                                 dtype=str(obj.dtype),
                                 shape=obj.shape)
+        elif sys.version_info >= (3, 0) and isinstance(obj, range):
+            return list(obj)
         elif isinstance(obj, numpy.generic):
             return obj.item()
         elif isinstance(obj, complex):
@@ -207,7 +223,7 @@ def json_dumper(obj, objects_encode=True):
             return obj.toJSON()
 
 
-def json_loader(object_pairs, cls=dict):
+def json_loader(object_pairs, cls=dict, null_to=None):
     """
     Load json-objects generated by the json_dumper function
 
@@ -215,6 +231,8 @@ def json_loader(object_pairs, cls=dict):
 
     :param cls: dicitonary class to use
 
+    :param null_to: convert null to user defined value (None by default)
+
     :return: ojbect
     """
     from omas import ODS
@@ -228,16 +246,24 @@ def json_loader(object_pairs, cls=dict):
 
     dct = cls()
     for x, y in object_pairs:
+        if null_to is not None and y is None:
+            y = null_to
         if isinstance(y, list):
-            if len(y) and isinstance(y[0], (dict, ODS)):
+            if len(y) and isinstance(y[0], ODS):
                 dct[x] = cls()
                 for k in range(len(y)):
                     dct[x][k] = y[k]
             else:
+                if null_to is not None:
+                    for k in range(len(y)):
+                        if y[k] is None:
+                            y[k] = null_to
                 dct[x] = y
         else:
             dct[x] = y
 
+    if "dtype" in dct:  # python2/3 compatibility
+        dct["dtype"] = dct["dtype"].replace('S', 'U')
     if '__ndarray_tolist__' in dct:
         return numpy.array(dct['__ndarray_tolist__'], dtype=dct['dtype']).reshape(dct['shape'])
     elif '__ndarray_tolist_real__' in dct and '__ndarray_tolist_imag__' in dct:
@@ -305,8 +331,8 @@ def remove_parentheses(inv, replace_with=''):
 
 def closest_index(my_list, my_number=0):
     """
-    Given a SORTED iterable (a numeric array or list of numbers) and a numeric scalar my_number, find the index of the
-    number in the list that is closest to my_number
+    Given a SORTED iterable (a numeric array or list of numbers) and a numeric scalar my_number,
+    find the index of the number in the list that is closest to my_number
 
     :param my_list: Sorted iterable (list or array) to search for number closest to my_number
 
@@ -316,24 +342,12 @@ def closest_index(my_list, my_number=0):
 
     :note: If two numbers are equally close, returns the index of the smallest number.
     """
-    import bisect
-
     if not hasattr(my_list, '__iter__'):
-        raise TypeError("closestIndex() in utils_math.py requires an iterable as the first argument. Got "
-                        "instead: {:}".format(my_list))
-
+        raise TypeError("closestIndex() requires an iterable as the first argument. Got instead: {:}".format(my_list))
     if not is_numeric(my_number):
-        if hasattr(my_number, '__iter__') and len(my_number) == 1 and is_numeric(my_number[0]):
-            printw('Warning: closestIndex got a len()=1 iterable instead of a scalar for my_number. my_number[0] will '
-                   'be used, but please input a scalar next time.')
-            # Before, the function would run without an error if given a one element array, but it would not return the
-            # correct answer.
-            my_number = my_number[0]
-            printd('my_number is now {:}'.format(my_number))
-        else:
-            raise TypeError("closestIndex() in utils_math.py requires a numeric scalar as the second argument. Got "
-                            "instead: {:}".format(my_number))
+        raise TypeError("closestIndex() requires a numeric scalar as the second argument. Got instead: {:}".format(my_number))
 
+    import bisect
     pos = bisect.bisect_left(my_list, my_number)
     if pos == 0:
         return 0
@@ -368,6 +382,23 @@ def compare_version(version1, version2):
     return (normalize(version1) > normalize(version2)) - (normalize(version1) < normalize(version2))
 
 
+def underline_last(text, offset=0):
+    '''
+    Utility function to underline the last part of a path
+
+    :param text: text to underline
+
+    :param offset: add offset to underling
+
+    :return: original text with underline on a new line
+    '''
+    index = [i for i, x in enumerate(text) if x in ['.', ' ']][-1]
+    if text[index] == '.':
+        index += 1
+    underline = ' ' * (index + offset) + '^' * (len(text) - index)
+    return text + '\n' + underline
+
+
 # ----------------------------------------------
 # handling of OMAS json structures
 # ----------------------------------------------
@@ -520,7 +551,7 @@ def p2l(key):
     if isinstance(key, (int, numpy.integer)):
         return [int(key)]
 
-    if isinstance(key, basestring) and '.' not in key:
+    if isinstance(key, basestring) and not ('.' in key or '[' in key):
         if len(key):
             return [key]
         else:
@@ -616,10 +647,10 @@ def l2o(path):
     return '.'.join(filter(None, map(str, path)))
 
 
-_o2u_pattern = re.compile('\.[0-9:]+')
-_o2u_pattern_no_split = re.compile('^[0-9:]+')
-_i2o_pattern = re.compile('\[([:0-9]+)\]')
-_o2i_pattern = re.compile('\.([:0-9]+)')
+_o2u_pattern = re.compile(r'\.[0-9:]+')
+_o2u_pattern_no_split = re.compile(r'^[0-9:]+')
+_i2o_pattern = re.compile(r'\[([:0-9]+)\]')
+_o2i_pattern = re.compile(r'\.([:0-9]+)')
 
 
 def o2u(path):
@@ -700,45 +731,6 @@ def trim_common_path(p1, p2):
     return p1[both.index(None):], p2[both.index(None):]
 
 
-def ids_cpo_mapper(ids, cpo=None):
-    '''
-    translate (some) IDS fields to CPO
-
-    :param ids: input omas data object (IDS format) to read
-
-    :param cpo: optional omas data object (CPO format) to which to write to
-
-    :return: cpo
-    '''
-    from omas import ODS
-    if cpo is None:
-        cpo = ODS()
-    cpo.consistency_check = False
-
-    for itime in range(len(ids['core_profiles.time'])):
-
-        if 'equilibrium' in ids:
-            cpo['equilibrium'][itime]['time'] = ids['equilibrium.time'][itime]
-            cpo['equilibrium'][itime]['profiles_1d.q'] = ids['equilibrium.time_slice'][itime]['profiles_1d.q']
-            cpo['equilibrium'][itime]['profiles_1d.rho_tor'] = ids['equilibrium.time_slice'][itime]['profiles_1d.rho_tor']
-            for iprof in range(len(ids['equilibrium.time_slice'][itime]['profiles_2d'])):
-                cpo['equilibrium'][itime]['profiles_2d'][iprof]['psi'] = ids['equilibrium.time_slice'][itime]['profiles_2d'][iprof]['psi']
-
-        if 'core_profiles' in ids:
-            cpo['coreprof'][itime]['te.value'] = ids['core_profiles.profiles_1d'][itime]['electrons.temperature']
-            cpo['coreprof'][itime]['ne.value'] = ids['core_profiles.profiles_1d'][itime]['electrons.density']
-            pdim = len(cpo['coreprof'][itime]['te.value'])
-            idim = len(ids['core_profiles.profiles_1d[0].ion'])
-            cpo['coreprof'][itime]['ni.value'] = numpy.zeros((pdim, idim))
-            cpo['coreprof'][itime]['ti.value'] = numpy.zeros((pdim, idim))
-            for iion in range(len(ids['core_profiles.profiles_1d'][itime]['ion'])):
-                if 'density' in ids['core_profiles.profiles_1d'][itime]['ion'][iion]:
-                    cpo['coreprof'][itime]['ni.value'][:, iion] = ids['core_profiles.profiles_1d'][itime]['ion'][iion]['density']
-                cpo['coreprof'][itime]['ti.value'][:, iion] = nominal_values(ids['core_profiles.profiles_1d'][itime]['ion'][iion]['temperature'])
-
-    return cpo
-
-
 def omas_info(structures, imas_version=omas_rcparams['default_imas_version']):
     '''
     This function returns an ods with the leaf nodes filled with their property informations
@@ -759,7 +751,6 @@ def omas_info(structures, imas_version=omas_rcparams['default_imas_version']):
         from omas import ODS
         _info_structures[imas_version] = ODS(imas_version=imas_version, consistency_check=False)
     ods = _info_structures[imas_version]
-    ods.consistency_check = False
 
     for structure in structures:
         if structure not in ods:
@@ -796,3 +787,105 @@ def omas_info_node(key, imas_version=omas_rcparams['default_imas_version']):
     except KeyError:
         pass
     return tmp
+
+
+def recursive_interpreter(me, interpret_method=ast.literal_eval, dict_cls=OrderedDict):
+    '''
+    Traverse dictionaries and list to convert strings to int/float when appropriate
+
+    :param me: root of the dictionary to traverse
+
+    :param interpret_method: method used for conversion (ast.literal_eval by default)
+
+    :param dict_cls: dictionary class to use
+
+    :return: root of the dictionary
+    '''
+    if isinstance(me, list):
+        keys = range(len(me))
+    elif isinstance(me, dict):
+        keys = me.keys()
+
+    for kid in keys:
+        if me[kid] is None:
+            continue
+        elif isinstance(me[kid], (list, dict)):
+            if not isinstance(me[kid], dict_cls):
+                tmp = me[kid]
+                me[kid] = dict_cls()
+                me[kid].update(tmp)
+            recursive_interpreter(me[kid], interpret_method=interpret_method, dict_cls=dict_cls)
+            if isinstance(kid, basestring) and kid.startswith('__integer_'):
+                me[int(re.sub('__integer_([0-9]+)__', r'\1', kid))] = me[kid]
+                del me[kid]
+        else:
+            try:
+                me[kid] = interpret_method(me[kid])
+            except (ValueError, SyntaxError) as _excp:
+                pass
+            if isinstance(me[kid], basestring) and ' ' in me[kid]:
+                try:
+                    values = []
+                    for item in re.split(r'[ |\t]+', me[kid].strip()):
+                        values.append(float(item))
+                    me[kid] = numpy.array(values)
+                except ValueError:
+                    pass
+    return me
+
+
+def recursive_encoder(me):
+    '''
+    Traverse dictionaries and list to convert entries as appropriate
+
+    :param me: root of the dictionary to traverse
+
+    :return: root of the dictionary
+    '''
+    if isinstance(me, list):
+        keys = range(len(me))
+    elif isinstance(me, dict):
+        keys = me.keys()
+
+    for kid in keys:
+        if me[kid] is None:
+            continue
+        elif isinstance(me[kid], (list, dict)):
+            recursive_encoder(me[kid])
+        else:
+            if isinstance(me[kid], numpy.ndarray):
+                me[kid] = ' '.join([repr(x) for x in me[kid]])
+            else:
+                me[kid] = str(me[kid])
+        # omas encoding of integer keys
+        if isinstance(kid, int):
+            me['__integer_%d__' % kid] = me[kid]
+            del me[kid]
+    return me
+
+
+def get_actor_io_ids(filename):
+    '''
+    Parse IMAS Python actor script and return actor input and output IDSs
+
+    :param filename: filename of the IMAS Python actor
+
+    :return: tuple with list of input IDSs and output IDSs
+    '''
+    import ast
+    with open(filename, 'r') as f:
+        module = ast.parse(f.read())
+    actor = os.path.splitext(os.path.split(filename)[-1])[0]
+    function_definitions = [node for node in module.body if isinstance(node, ast.FunctionDef)]
+    docstring = ast.get_docstring([f for f in function_definitions if f.name == actor][0])
+    ids_in = []
+    ids_out = []
+    for line in docstring.split('\n'):
+        if 'codeparams' in line:
+            pass
+        elif line.strip().startswith(':param result:'):
+            ids_out = list(map(lambda x: x.strip()[:-1], line.split(':')[2].strip(', ').split(',')))
+            break
+        elif line.strip().startswith(':param '):
+            ids_in.append(line.split(':')[2].strip())
+    return ids_in, ids_out
