@@ -21,6 +21,7 @@ import copy
 # OMAS imports
 from omas import *
 from omas.omas_utils import *
+from omas.tests import warning_setup
 
 
 class TestOmasUtils(unittest.TestCase):
@@ -64,10 +65,12 @@ class TestOmasUtils(unittest.TestCase):
         diff_prof5 = different_ods(ods2, ods3)
         assert isinstance(diff_prof5, list)
         assert 'name' in ' '.join(diff_prof5)
+        return
 
     def test_printe(self):
         printe('printe_test,', end='')
         printw('printw_test', end='')
+        return
 
     def test_is_numeric(self):
         assert is_numeric(5) is True
@@ -76,9 +79,11 @@ class TestOmasUtils(unittest.TestCase):
         assert is_numeric({'blah': 'blah'}) is False
         assert is_numeric([]) is False
         assert is_numeric(None) is False
+        return
 
     def test_remove_parentheses(self):
         assert remove_parentheses('zoom(b(la)h)what', replace_with='|') == 'zoom|what'
+        return
 
     def test_closest_index(self):
         # Basic tests
@@ -92,6 +97,7 @@ class TestOmasUtils(unittest.TestCase):
         self.assertRaises(TypeError, closest_index, 5, 5)  # First arg is not a list --> TypeError
         self.assertRaises(TypeError, closest_index, [1, 2, 3], 'string_not_number')
         self.assertRaises(TypeError, closest_index, [1, 2, 3], [3, 2, 1])  # Can't call w/ list as 2nd arg unless len=1
+        return
 
     def test_list_structures(self):  # Also tests dict_structures
         struct_list = list_structures(omas_rcparams['default_imas_version'])
@@ -107,6 +113,7 @@ class TestOmasUtils(unittest.TestCase):
         assert 'pf_active' in struct_dict2.keys()
         assert all([item in struct_dict.keys() for item in struct_list])
         assert all([item in struct_dict2.keys() for item in struct_list2])
+        return
 
     def test_omas_info(self):
         get_list = ['pf_active', 'thomson_scattering', 'charge_exchange']
@@ -118,6 +125,7 @@ class TestOmasUtils(unittest.TestCase):
             assert isinstance(ods_info_pfa['pf_active.circuit.0.connections.documentation'], basestring)
         ods_info_list = omas_info(get_list)
         assert all([item in ods_info_list for item in get_list])
+        return
 
     def test_o2u(self):
         assert o2u('equilibrium.time_slice.0.global_quantities.ip') == 'equilibrium.time_slice.:.global_quantities.ip'
@@ -125,15 +133,20 @@ class TestOmasUtils(unittest.TestCase):
         assert o2u('2') == ':'
         assert o2u('equilibrium') == 'equilibrium'
         assert o2u('equilibrium.2') == 'equilibrium.:'
+        return
 
     def test_set_time_array(self):
         ods = ODS()
         ods.set_time_array('equilibrium.vacuum_toroidal_field.b0', 0, 0.1)
         ods.set_time_array('equilibrium.vacuum_toroidal_field.b0', 1, 0.2)
+        return
 
     def test_info(self):
         omas_info('equilibrium')
         omas_info(None)
+        return
+
+    # End of TestOmasUtils class
 
 
 if __name__ == '__main__':
